@@ -173,10 +173,10 @@ static int document_len(lua_State *L)
 static int document_page_iterator(lua_State *L)
 {
   Document **d = check_document(L, 1);
-  int i = (int)luaL_checkinteger(L, 2);
+  int i = luaL_checkinteger(L, 2);
   i = i + 1;
   if (i <= (*d)->countPages()) {
-    lua_pushnumber(L, i);               // new counter
+    lua_pushinteger(L, i);               // new counter
     push_page(L, (*d)->page(i-1), false); // page
     return 2;
   } else
@@ -190,7 +190,7 @@ static int document_pages(lua_State *L)
   (void) check_document(L, 1);
   lua_pushcfunction(L, document_page_iterator); // iterator function
   lua_pushvalue(L, 1);          // document
-  lua_pushnumber(L, 0);         // counter
+  lua_pushinteger(L, 0);         // counter
   return 3;
 }
 
@@ -295,8 +295,11 @@ static int document_replaceSheets(lua_State *L)
 static int document_runLatex(lua_State *L)
 {
   Document **d = check_document(L, 1);
+  String docname;
+  if (!lua_isnoneornil(L, 2))
+    docname = luaL_checklstring(L, 2, nullptr);
   String log;
-  int result = (*d)->runLatex(log);
+  int result = (*d)->runLatex(docname, log);
 
   if (result == Document::ErrNone) {
     lua_pushboolean(L, true);
